# FILE DESCRIPTION: 2_DADA2_Pipeline.R ---------------------------------------------
#
# DESCRIPTION : 16S rRNA Gene Amplicon Sequencing Analysis using DADA2 Pipeline
#
# USAGE: 
#
#  REQUIREMENTS:  Please load packages listed below.
#  BUGS: --
#  NOTES:  ---
#  AUTHOR:  Berra Erkosar, berra.erkosarcombe@unil.ch
#  COMPANY:  UNIL, Lausanne, Switzerland


library(dada2) 
packageVersion("dada2")
library(phyloseq)
packageVersion("phyloseq")
library(Biostrings) 
packageVersion("Biostrings")
library(ggplot2) 
packageVersion("ggplot2")
require("genefilter")

setwd("")

#File Path
path <- "" 
list.files(path)

# Forward and reverse fastq filenames have format: SAMPLENAME_R1_001.fastq and SAMPLENAME_R2_001.fastq
fnFs <- sort(list.files(path, pattern="_R1_001", full.names = TRUE))
fnRs <- sort(list.files(path, pattern="_R2_001", full.names = TRUE))
# Extract sample names
sample.names <- sapply(strsplit(basename(fnFs), "_"), `[`, 1)

plotQualityProfile(fnFs[1:12])
plotQualityProfile(fnRs[1:12])
plotQualityProfile(fnFs[13:24])
plotQualityProfile(fnRs[13:24])
plotQualityProfile(fnFs[25:36])
plotQualityProfile(fnRs[25:36])
plotQualityProfile(fnRs[37:45])
plotQualityProfile(fnRs[37:45])


# Place filtered files in filtered/ subdirectory
filtFs <- file.path(path, "filtered", paste0(sample.names, "_F_filt.fastq"))
filtRs <- file.path(path, "filtered", paste0(sample.names, "_R_filt.fastq"))
names(filtFs) <- sample.names
names(filtRs) <- sample.names

out <- filterAndTrim(fnFs, filtFs, fnRs, filtRs, truncLen=c(240,160),
              maxN=0, maxEE=c(1,1), truncQ=2, rm.phix=TRUE,
              compress=TRUE, multithread=TRUE, trimLeft=c(19,20)) 
head(out)

errF <- learnErrors(filtFs, multithread=TRUE)
errR <- learnErrors(filtRs, multithread=TRUE)

#plotErrors(errF, nominalQ=TRUE)

dadaFs <- dada(filtFs, err=errF, multithread=TRUE)
dadaFs[[1]]

dadaRs <- dada(filtRs, err=errR, multithread=TRUE)
dadaRs[[1]]

help("dada-class")

# Merge paired ends
mergers <- mergePairs(dadaFs, filtFs, dadaRs, filtRs, verbose=TRUE)
# Inspect the merger data.frame from the first sample
head(mergers[[1]])

#Construct sequence table
seqtab <- makeSequenceTable(mergers)
dim(seqtab)


#Inspect distribution of sequence lengths
table(nchar(getSequences(seqtab)))


#remove chimeras
seqtab.nochim <- removeBimeraDenovo(seqtab, method="consensus", multithread=TRUE, verbose=TRUE)
dim(seqtab.nochim)
sum(seqtab.nochim)/sum(seqtab)
#[1] 0.7510093

#Track reads through pipeline
getN <- function(x) sum(getUniques(x))
track <- cbind(out, sapply(dadaFs, getN), sapply(dadaRs, getN), sapply(mergers, getN), rowSums(seqtab.nochim))
# If processing a single sample, remove the sapply calls: e.g. replace sapply(dadaFs, getN) with getN(dadaFs)
colnames(track) <- c("input", "filtered", "denoisedF", "denoisedR", "merged", "nonchim")
rownames(track) <- sample.names
head(track)

#assignTaxonomy using Silva 
taxa <- assignTaxonomy(seqtab.nochim, "~/Documents/UNIL/MonthlySampling/2018_EmeryKesnerova/16S/fastq/silva_nr_v132_train_set.fa.gz", multithread=TRUE)
taxa <- addSpecies(taxa, "~/Documents/UNIL/MonthlySampling/2018_EmeryKesnerova/16S/fastq/silva_species_assignment_v132.fa.gz")

taxa.print <- taxa # Removing sequence rownames for display only
rownames(taxa.print) <- NULL
head(taxa.print, 20)

#Data frame containing sample information
samdf = read.csv("03_df_sampleinfo.csv")
rownames(samdf) = samdf$sample_name

#Create a phyloseq object
ps <- phyloseq(otu_table(seqtab.nochim, taxa_are_rows=F), 
               sample_data(samdf), 
               tax_table(taxa))
sample_data(ps)  


#Remove the Mock community              
ps <- prune_samples(sample_names(ps) != "x-Mock", ps) # Remove mock sample

#Filter out Eukaryota, mitochondria and chloroplast reads
filt.ps <- subset_taxa(ps, Order!="Chloroplast", prunesamples=TRUE)
filt.ps <- subset_taxa(filt.ps, Kingdom!="Eukaryota", prunesamples=TRUE)
filt.ps <- subset_taxa(filt.ps, Family!="Mitochondria", prunesamples=TRUE)

# Compared taxa that are detected in water control and samples. 
#Taxa detected in water do not match the taxa in samples
# Water sample removed
filt.ps2 <- prune_samples(sample_names(filt.ps) != "x-H2O", filt.ps) 
filt.ps3=filter_taxa(filt.ps2, filterfun_sample(kOverA(2, 10)), TRUE)
table = merge( tax_table(filt.ps3),t(otu_table(filt.ps3)), by="row.names")

write.csv(table, "03_df_filt_16S.csv")
