# FILE DESCRIPTION: 3_Figures_1_S1_S2_S3.R ---------------------------------------------
#
# DESCRIPTION : Code to get Figures 1 + supplementary S1-3.
#
# USAGE: 
#
#  REQUIREMENTS:  Please load packages listed below.
#  BUGS: --
#  NOTES:  ---
#  AUTHOR:  Lucie Kesnerova, lucie.kesnerova@unil.ch; Olivier Emery
#  COMPANY:  UNIL, Lausanne, Switzerland

setwd("")

# Fig 1 ----------------------------------------------------------

library(multcomp)
library(plyr)
library(reshape2)
library(scales)   
library(ggbeeswarm)
library(ggplot2)
library(tidyr)
library(ggbiplot)
library(vegan)

# load data
dt1 <- read.csv("02_df_mm_calc.csv") # dataset 1 containing data for monthly sampled bees
dt1$X <- NULL# get rid of not needed
dt1$Target <- factor(dt1$Target)
levels(dt1$Target)
# keep 'univ' data separately
univ <- dt1[dt1$Target=="univ",]
dt1 <- dt1[dt1$Target!="univ",]


#### Fig 1A - Mean abundances monthly ####

##################### FUNCTION TO CALCULATE MEANS; MEDIANS.... ####
# generate new dataset containing means, medians, SD, SE, ci for each target and month
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult # when less than 30 samples, CI is not presice -> use SD
  return(datac)
}

#####################################

# remove lines in which the target is not detected (=> to get mean cell number of non core targets only when they are detected by qPCR)
dtDetected <- dt1[dt1$Present==1,] # undetected values are vizualized in Fig. S3
# use the function above to get mean+SE values
stat <- summarySE(dtDetected, measurevar="CellNum_norm", groupvars=c("Date", "Target"), na.rm = TRUE,conf.interval=.95, .drop=TRUE)
colnames(stat) <- c("Date", "Target","N","mean_CellNum_norm","SD","SE", "CI") # rename
stat$Date <- as.factor(stat$Date)

# add corresponding color and make the non-core membars in dashed line
cols2=c("#F0E442","#009E73","#56B4E9","#0072B2","#D55E00","#E69F00","#CC79A7") # colors
lineTypes2=c("dotted", "solid","solid","solid","dotted","solid","solid")
lineTypes3<-as.vector(stat$Target)
lineTypes3<-replace(lineTypes3, lineTypes3=='Fp', 'dotted')
lineTypes3<-replace(lineTypes3, lineTypes3=='Ba', 'dotted')
lineTypes3<-replace(lineTypes3, lineTypes3=='F4', 'solid')
lineTypes3<-replace(lineTypes3, lineTypes3=='F5', 'solid')
lineTypes3<-replace(lineTypes3, lineTypes3=='Ga', 'solid')
lineTypes3<-replace(lineTypes3, lineTypes3=='Sa', 'solid')
lineTypes3<-replace(lineTypes3, lineTypes3=='Bi', 'solid')

fig1A = ggplot(stat, aes(x = Date, y = mean_CellNum_norm, colour=Target, group=Target))+
  geom_line(aes(linetype=lineTypes3),size = 1)+
  scale_color_manual(values = cols2)+
  scale_linetype_manual(values=lineTypes3)+
  geom_errorbar(aes(ymin=mean_CellNum_norm-SE, ymax=mean_CellNum_norm+SE), width=0.25, size=0.5) +
  scale_x_discrete(name = "Date")+
  scale_y_log10(name = "Mean phylotype loads", 
                breaks=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(NA,3e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  theme_bw()+
  theme(axis.text.x=element_text(angle = 90, vjust = -0.04))
print(fig1A)
ggsave(plot=fig1A,height=8,width=18,dpi=200, filename="MM_Fig1A.pdf", useDingbats=FALSE)
#####


#### Fig 1B - F vs W phylotype loads ####

# define custom mean function
plot.mean <- function(x) {
  m <- mean(x)
  c(y = m, ymin = m, ymax = m)
}
#function to add number of observations in the plot
give.n <- function(x){
  return(c(y = 10, label = length(x)))   # play with y to find the perfect position
}

# calculate SUM of the 7 phylotypes
sum <- aggregate(dt1$CellNum_norm, by=list(Category=dt1$Sample_ID,dt1$Date,dt1$Bee_type), FUN=sum) # 566 bees
colnames(sum) <- c("Sample_ID","Date","Bee_type","SUM" ) # change names
# add the 'sum' data to the dataset
colnames(sum)[4] <- "CellNum_norm" 
sum$Target <- "SUM"
dtB <- merge(dt1,sum, all=T)

# get rid of bees in which the qPCR signal was below threshold
dtB$Present[dtB$Target=="SUM"] <- "1"
dtB <- dtB[dtB$Present!=0,]
dtB <- dtB[!is.na(dtB$Target),] # get rid of rows with generated NAs

dtB$x.labels <- paste(dtB$Bee_type, dtB$Target, sep = "\n") # to make subcategories on x axis
dtB$x.labels <- factor(dtB$x.labels, levels = c("F\nGa","W\nGa","F\nSa","W\nSa","F\nBi","W\nBi","F\nF4","W\nF4",
                                                "F\nF5","W\nF5","F\nBa","W\nBa","F\nFp","W\nFp","F\nSUM","W\nSUM"))  # give it my order

fig1B <- ggplot(data = dtB, aes(x = x.labels, y = CellNum_norm)) + 
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9"))+
  geom_point(data = dtB, aes(color=Bee_type),position = position_jitter(width = 0.35, height = 0), size=1) + 
  scale_y_log10(name = "Number of bacteria per bee", limits=c(1e+03,2e+10),
                breaks=c(1e+04,1e+05,1e+06,1e+07,1e+08,1e+09,1e+10),
                labels=c(1e+04,1e+05,1e+06,1e+07,1e+08,1e+09,1e+10)) + # logarithmic scale
  scale_x_discrete()+ 
  stat_summary(data=dtB[dtB$Target == "Ga",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(data=dtB[dtB$Target == "Sa",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(data=dtB[dtB$Target == "Bi",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(data=dtB[dtB$Target == "F4",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(data=dtB[dtB$Target == "F5",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(data=dtB[dtB$Target == "Ba",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(data=dtB[dtB$Target == "Fp",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(data=dtB[dtB$Target == "SUM",], fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(fun.data = give.n, geom = "text") + # add number of observations
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
print(fig1B)
ggsave("MM_Fig1B.pdf",fig1B,height=5,width=10,limitsize = FALSE)

# numbers of bees below the threshold of detection
nrow(dt1[dt1$Target=="F4" & dt1$Bee_type=="F" & dt1$Present==0,]) # 9 foragers without F4 bacterium
nrow(dt1[dt1$Target=="Ba" & dt1$Bee_type=="F" & dt1$Present==0,]) # 22 foragers without Ba bacterium
nrow(dt1[dt1$Target=="Fp" & dt1$Bee_type=="F" & dt1$Present==0,]) # 88 foragers without Fp bacterium
nrow(dt1[dt1$Target=="Fp" & dt1$Bee_type=="W" & dt1$Present==0,]) # 57 winter bees without Fp bacterium


#### Fig 1C - F vs W 16S loads ####

fig1C <- ggplot(data = univ, aes(x = Bee_type, y = CopyNum_norm, fill= Bee_type)) + 
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9"))+
  geom_beeswarm(data = univ, aes(color=Bee_type), cex = 2, size=2) + 
  scale_y_log10() + # logarithmic scale
  scale_x_discrete()+ 
  stat_summary(data=univ, fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  annotation_logticks(sides="l")+ # add logtick marks
  #stat_summary(fun.data = give.n, geom = "text") + # add number of observations
  theme_bw()
print(fig1C)
ggsave("MM_Fig1C.pdf",fig1C,height=5,width=5,limitsize = FALSE)


#### Fig 1D - 100% STACKED BARPLOT ####

# make order in Sample_IDs (numeric)
dt1<-dt1[order(dt1$Sample_ID),]
#Create a custom color scale
dt1$Target <- factor(dt1$Target,levels=c("Fp","Ba","F5","F4","Bi","Sa","Ga")) # to plot Targets in barplot everytime in the same order
levels(dt1$Target) # "Fp" "Ba" "F5" "F4" "Bi" "Sa" "Ga"
cols=c("#D55E00","#F0E442","#0072B2","#56B4E9","#009E73","#CC79A7","#E69F00") # specify colors

#PLOT 100% STACKED BARPLOTS for each bee - RELATIVE COMMUNITY PROFILE
fig1D <- ggplot(dt1, aes(x = Sample_ID, y = CellNum_norm, fill = Target))+
  geom_bar(position = "fill",stat = "identity") +
  scale_y_continuous(labels = percent_format())+
  scale_fill_manual(values = cols)+
  geom_vline(xintercept=c(22,48,74,122,146,170,194,218,242,266,290,314,338,362,386,410,434,458,482,506,530,554,578))+ # make optical dividers between months 
  scale_x_continuous(breaks=c(1,22,48,74,122,146,170,194,218,242,266,290,314,338,362,386,410,434,458,482,506,530,554,578,600),
                     labels=c(1,22,48,74,122,146,170,194,218,242,266,290,314,338,362,386,410,434,458,482,506,530,554,578,600))+ #numbers of last bees of the month
  theme(panel.background = element_blank(),axis.text.x=element_text(angle=90,hjust=1,vjust=0.5),
        legend.key.size = unit(0.5, "cm"), legend.text = element_text(size=6),legend.title = element_text(size=6))
print(fig1D)

ggsave(plot=fig1D,height=8,width=18,dpi=200, filename="MM_Fig1D.pdf", useDingbats=FALSE)


#### Fig 1E - Shannon's Effective Number of species ####

dtbeta = dt1[,c(1,3,5,6,18)]
dtbwide = dtbeta %>% spread(Target, CellNum_norm, convert = FALSE) 
dtbwide = droplevels(dtbwide)
dtbwide = transform(dtbwide,  Date = as.Date(as.character(Date), "%y%m%d"))
measures = dtbwide[,4:10]
measures[is.na(measures)] = 0
# Get Shannon diversity indexes
div2 = diversity(measures)
dtbwide$Neff = exp(div2)

#function to add number of observations in the plot
give.n <- function(x){
  return(c(y = 0.1, label = length(x)))   # play with y to find the perfect position
}

# Plot effective number of species according to bee type
plotNeff = ggplot(data = dtbwide, aes(x = Bee_type, y = Neff, fill= Bee_type)) + 
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9"))+
  geom_beeswarm(data = dtbwide, aes(color=Bee_type), cex = 2, size=2) + 
  scale_y_continuous(name = "Effective Number of Species per Gut") + 
  scale_x_discrete()+ 
  stat_summary(data=dtbwide, fun.data="plot.mean", geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  stat_summary(fun.data = give.n, geom = "text") + # add number of observations
  theme_bw()
print(plotNeff)
ggsave(plotNeff, filename="MM_Fig1E.pdf",height=5,width=6, dpi=200, useDingbats=FALSE)


###### Fig 1D  Principal component analysis ####################################################
# Main source: https://www.r-bloggers.com/computing-and-visualizing-pca-in-r/

gm<-dt1[,c(3,1,6,18)] # Select Bee_ID, target, Bee_type and CellNum_norm only
gm<-reshape(gm,timevar = "Target",idvar=c("Sample_ID"),direction="wide") # Reshape data
gm<-gm[,-c(4,6,8,10,12,14)] # Remove redundant data
#strip off the sample ids and convert them to row names so that the data matrix contains only sequence count data
row.names(gm) <- gm$Bee_ID
gm<-gm[,-c(1)]
colnames(gm)<-c("Bee_type","Ba","Bi","F4","F5","Fp","Ga","Sa")

gm[gm == 0] <- 1 # replace all zero values with '1'
gmlog<-log(gm[,-c(1)])
gmBeeType<-gm[,1]
gm.pca <- prcomp(gmlog,
                 center = TRUE,
                 scale. = TRUE)
print(gm.pca)
plot(gm.pca,type="l")
summary(gm.pca)
g <- ggbiplot(gm.pca, obs.scale = 1, var.scale = 1, 
              groups = gmBeeType, ellipse = TRUE, 
              circle = F)
g <- g + geom_point(aes(colour=gmBeeType), size = 1)
g <- g + scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9"))
g <- g + theme_bw()+theme(legend.direction = 'horizontal', 
                          legend.position = 'top') + ggtitle("Principal Component Analysis \n from gut microbiota species abundances")
print(g)
ggsave("MM_Fig1F.pdf",g,height=5,width=8,limitsize = FALSE)



# Fig S1 ----------------------------------------------------------
#### Fig S1 NON_CORE BACTERIA PREVALENCE (%) ####
dtp1 <- dt1[dt1$Target=="Ba",]
dtp2 <- dt1[dt1$Target=="Fp",]
dtp3 <- dt1[dt1$Target=="F4",]
dt <- rbind(dtp1,dtp2,dtp3) # info about presence/absence in bee is already there
rm(dtp1,dtp2,dtp3)
dt$Target <- factor(dt$Target)
levels(dt$Target)

# # get tables of counts of pos and neg bees on colonization with the target
dt <- dt[,c(1,3,5,16)] # Target, Sample_ID, Date, Present
dt$Target <- factor(dt$Target)
ft <- ftable(dt[,c(1,3,4)]) # Target, Date, Present
ft <- as.data.frame(ft) # get counts of pos and neg bees


# Firm-4 prevalence
f4 <- ggplot(ft[ft$Target=="F4",], aes(x = Date, y = Freq, fill = Present, label=Freq))+
  geom_bar(position = "fill",stat = "identity", color="black") +
  scale_fill_manual(values=c("white","grey"))+
  geom_text(aes(y=c(0.1)),size = 3, position = position_stack(vjust = 0.5))+
  scale_y_continuous(name = "Lactobacillus Firm-4 prevalence")+
  theme_bw()+
  theme(axis.line = element_line(colour = "black"),panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),panel.border = element_blank(),panel.background = element_blank()) # no grid in graph
print(f4)
# B. apis prevalence
ba <- ggplot(ft[ft$Target=="Ba",], aes(x = Date, y = Freq, fill = Present, label=Freq))+
  geom_bar(position = "fill",stat = "identity", color="black") +
  scale_fill_manual(values=c("white","grey"))+
  geom_text(aes(y=c(0.1)),size = 3, position = position_stack(vjust = 0.5))+
  scale_y_continuous(name = "B. apis prevalence")+
  theme_bw()+
  theme(axis.line = element_line(colour = "black"),panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),panel.border = element_blank(),panel.background = element_blank()) # no grid in graph
print(ba)
# F. perrara prevalence
fp <- ggplot(ft[ft$Target=="Fp",], aes(x = Date, y = Freq, fill = Present, label=Freq))+
  geom_bar(position = "fill",stat = "identity", color="black") +
  scale_fill_manual(values=c("white","grey"))+
  geom_text(aes(y=c(0.1)),size = 3, position = position_stack(vjust = 0.5))+
  scale_y_continuous(name = "F. perrara prevalence")+
  theme_bw()+
  theme(axis.line = element_line(colour = "black"),panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),panel.border = element_blank(),panel.background = element_blank()) # no grid in graph
print(fp)

library(gridExtra)
plot = list(f4, ba, fp)
y <- marrangeGrob(plot, nrow=3, ncol=1) # to get more ggplots in ONE pdf 
ggsave(plot=y,height=15,width=21,dpi=200, filename="MM_FigS1.pdf", useDingbats=FALSE)



# Fig S2 ----------------------------------------------------------
#### Fig S2 SCAB vs Frischella ####

# function to add number of observations to the plot
give.n <- function(x){
  return(c(y = 10, label = length(x)))   # experiment with the multiplier to find the perfect position
}

dtp <- dt1[dt1$Target=="Fp",]
# store undetected data points separately
neg0 <- dtp[dtp$Scab=="0" & dtp$CellNum_norm==0,] # 130 bees without scab do not have detectable Frischella levels 
neg1 <- dtp[dtp$Scab=="1" & dtp$CellNum_norm<1,] # 15 bees with scab do not have detectable Frischella levels

#dtp <- dtp[dtp$CellNum_norm!=1,] # remove undetected data points
f <- neg0[neg0$Bee_type=="F",] # 83 F bees
w <- neg0[neg0$Bee_type=="W",] # 47 W bees
f1 <- neg1[neg1$Bee_type=="F",] # 5 F bees
w1 <- neg1[neg1$Bee_type=="W",] # 10 W bees

dtp$Scab <- as.factor(dtp$Scab)

scab <- ggplot(dtp, aes(x = Scab, y = CellNum_norm))+ 
  geom_beeswarm(aes(color=Bee_type),cex=1.7, size=1)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9"))+
  scale_y_log10(labels=c(1e+02,1e+03,1e+04,1e+05,1e+06,1e+07,1e+08), 
                breaks=c(1e+02,1e+03,1e+04,1e+05,1e+06,1e+07,1e+08))+
  stat_summary(data=dtp[dtp$Scab2 == "1",], fun.data="plot.mean",geom="errorbar", colour="black", width=0.8, size=0.5)+ # add mean line
  stat_summary(data=dtp[dtp$Scab2 == "0",], fun.data="plot.mean",geom="errorbar", colour="black", width=0.8, size=0.5)+ # add mean line
  stat_summary(fun.data = give.n, geom = "text") + # add number of observations
  theme_bw()
print(scab)
# datapoints below the threshold of detection were added manually in Illustrator
ggsave(plot=scab,height=4,width=5,dpi=200, filename="MM_FigS2.pdf", useDingbats=FALSE)


# Fig S3 ----------------------------------------------------------
### Fig S3 - individual bacteria monthly ###

dt <- dt1
# Plot trends in bacterial species one by one
Ga = ggplot(dt[dt$Target=="Ga",], aes(x = factor(Date), y = CellNum_norm))+
  geom_boxplot(fill="#E69F00")+ 
  scale_x_discrete(name = "Month")+
  ggtitle("Gilliamella apicola")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(1e+03,5e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  theme_bw()
print(Ga)

Sa = ggplot(dt[dt$Target=="Sa",], aes(x = factor(Date), y = CellNum_norm))+
  geom_boxplot(fill="#CC79A7")+ 
  scale_x_discrete(name = "Month")+
  ggtitle("Snodgrassella alvi")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(1e+03,5e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  theme_bw()
print(Sa)

Bi = ggplot(dt[dt$Target=="Bi",], aes(x = factor(Date), y = CellNum_norm))+
  geom_boxplot(fill="#009E73")+ 
  scale_x_discrete(name = "Month")+
  ggtitle("Bifidobacterium asteroides")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(1e+03,5e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  theme_bw()
print(Bi)

F5 = ggplot(dt[dt$Target=="F5",], aes(x = factor(Date), y = CellNum_norm))+
  geom_boxplot(fill="#0072B2")+ 
  scale_x_discrete(name = "Month")+
  ggtitle("Firm-5")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(1e+04,5e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  theme_bw()
print(F5)

F4 = ggplot(dt[dt$Target=="F4",], aes(x = factor(Date), y = CellNum_norm))+
  geom_boxplot(fill="#56B4E9")+ 
  scale_x_discrete(name = "Month")+
  ggtitle("Firm-4")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(1e+04,1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1e+04,1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(1e+03,5e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  geom_hline(yintercept = 1e+03, linetype=2)+
  theme_bw()
print(F4)

Ba = ggplot(dt[dt$Target=="Ba",], aes(x = factor(Date), y = CellNum_norm))+
  geom_boxplot(fill="#F0E442")+ 
  scale_x_discrete(name = "Month")+
  ggtitle("Bartonella apis")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(100,1000,1e+04,1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(100,1000,1e+04,1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(1e+03,5e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  geom_hline(yintercept = 1e+03, linetype=2)+
  theme_bw()
print(Ba)

Fp = ggplot(dt[dt$Target=="Fp",], aes(x = factor(Date), y = CellNum_norm))+
  geom_boxplot(fill="#D55E00")+ # outlier.shape=NA
  #geom_beeswarm(cex=0.8, size=1.5)+ 
  scale_x_discrete(name = "Month")+
  ggtitle("Frischella perrara")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(1000,1e+04,1e+05,1e+06,1e+07,1e+08,1e+09),
                labels=c(1000,1e+04,1e+05,1e+06,1e+07,1e+08,1e+09),
                limits=c(1e+03,5e+09)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  geom_hline(yintercept = 1e+03, linetype=2)+
  theme_bw()
print(Fp)

sum <- aggregate(dt$CellNum_norm, by=list(Category=dt$Sample_ID,dt$Date,dt$Bee_type), FUN=sum) # 566 bees
colnames(sum) <- c("Sample_ID","Date","Bee_type","SUM" ) # change names
SUM = ggplot(sum, aes(x = factor(Date), y = SUM))+
  geom_boxplot()+ 
  scale_x_discrete(name = "Month")+
  ggtitle("SUM")+
  scale_y_log10(name = "CellNum_norm per gut", 
                breaks=c(1e+06,1e+07,1e+08,1e+09,1e+10),
                labels=c(1e+06,1e+07,1e+08,1e+09,1e+10),
                limits=c(1e+06,2e+10)) + # logarithmic scale
  annotation_logticks(sides="l")+ # add logtick marks
  theme_bw()
print(SUM)


library(gridExtra)
plot = list(Ga,Sa,Bi,F5,F4,Ba,Fp,SUM)
y <- marrangeGrob(plot, nrow=4, ncol=2) # to get more ggplots in ONE pdf 
ggsave(plot=y,height=18,width=18,dpi=200, filename="MM_FigS3.pdf", useDingbats=FALSE)


