# FILE DESCRIPTION: 3_Plots_Stats_Fig2_S4.R ---------------------------------------------
#
# DESCRIPTION : Diversity and statistical analyses and visulaisatoin of the community data presented in Fig 2 and S4.
#
# USAGE: 
#
#  REQUIREMENTS:  Please load packages listed below.
#  BUGS: --
#  NOTES:  ---
#  AUTHOR:  Berra Erkosar, berra.erkosarcombe@unil.ch
#  COMPANY:  UNIL, Lausanne, Switzerland

library(ggplot2)
library(scales)
library(ggpubr)
library(magrittr)
library(ggbeeswarm)
library(tidyr)
library(vegan)
library(multcomp)

setwd("~/Documents/Berra's Docs/SwitchDrive/Kesnerova_et_al_codes_datasets")

#Sample Information
samdf = read.csv("03_df_sampleinfo2.csv")

#Data table with reads summed for phylotypes
phylosum = read.csv("03_df_16S_phylo.csv")

#qPCR data from same samples
qPCR = read.csv("02_df_pool_calc.csv")



#Calculate 16S copy numbers using qPCR data with Universal primers (normalized to actin)
#########################################################################################

#16S copy numbers
uni = qPCR[qPCR$Target=="univ",]
uni = uni[order(uni$Sample_ID),]

plot.mean <- function(x) {
  m <- mean(x)
  c(y = m, ymin = m, ymax = m)
}

### Fig 2A - universal primers ####
fig2A = ggplot(data = uni, aes(x = Bee_type, y = CopyNum_norm)) + 
  geom_beeswarm(aes(color=Bee_type),cex=2.5, size=2)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_y_log10( breaks=c(1e+09, 1e+10),
                 labels=c(1e+09, 1e+10),
                 limits=c(1e+08,4e+09)) + # logarithmic scale
  scale_x_discrete()+ 
  annotation_logticks(sides="l")+ # add logtick marks
  stat_summary(data=uni, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()
fig2A
ggsave("MM_Fig2A.pdf",fig2A,height=4,width=4,limitsize = FALSE)




#Calculate copy number for each taxa and divide each phylotype by the 16S loci number in the genome
###################################################################################################

#calculate ratios
ratios = phylosum[,7:49]
ratios[, -1] = lapply(ratios[, -1], function(x) x/sum(x))

copies = data.frame(row.names = (ratios$Group))
for (i in 1:42){
  numbers = ratios[,i+1]*uni$CopyNum_norm[i]
  copies = cbind(copies,numbers)
}
colnames(copies) = colnames(ratios[-1])
copies$Group = rownames(copies)

#Number of loci in each genome
n16sL = read.csv("Num16SLoci.csv") #This dataset can be obtained from Supplementary Table S7. 
colnames(n16sL)[1] <- "Group"
colnames(n16sL)[2] <- "Num16Sloci"

ncopies = merge(copies, n16sL, by="Group" )

nncopies = data.frame(row.names = (ncopies$Group))

for (i in 1:28){
  numbers = ncopies[i,2:43]/ncopies$Num16Sloci[i]
  nncopies = rbind(nncopies,numbers)
}

nncopies$Group = ncopies$Group


#copy numbers tall orientation
copynums=nncopies %>% gather(sample_name, CopyNumbers, 1:42)
copynums = merge(copynums,samdf)

#copy numbers wide orientation
row.names(nncopies) = nncopies$Group
nncopies$Group =NULL
copynumswide = t(nncopies)
colnames(copynumswide) = rownames(nncopies)



#Alpha-Diversity Analysis
#########################

#Calculate Shannon's diversity index
S = diversity(copynumswide, index = "shannon")
S = as.data.frame(S)

#Calculate effective number of species
Neff = exp(S$S)
S$Neff = Neff
S$sample_name = rownames(S)
S = merge(samdf, S, by="sample_name")

#One way ANOVA on effective number of species
mod=lm(Neff~bee_type,data=S)
anova(mod)
print(summary(glht(mod, linfct=mcp(bee_type="Tukey")), test = adjusted(type = "bonferroni")))


#Plot Fig 2B
ggplot(data = S, aes(x = bee_type, y = Neff)) + 
  geom_beeswarm(aes(color=bee_type),cex=1, size=2)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_y_continuous(limits=c(4.2,8.3))+
  stat_summary(data=S, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()+
  ggsave(file="EffNumSpSummedPhyloNormCorrected.pdf", width=4, height=4, useDingbats=FALSE)



#Beta-Diversity Analyses
########################

#Adonis on Bray-Curtis distances
Tdist = vegdist(copynumswide, method = "bray")
ado = adonis(Tdist ~ samdf$bee_type)
ado

#Project Bray-Curtis Distances on non=metric multidimensional scaling
iMDS <- metaMDS(copynumswide, k=2, distance = "bray", try=100)
data.scores <- as.data.frame(scores(iMDS))
data.scores$sample_name <- rownames(data.scores)
data.scores = merge(data.scores, samdf)

iMDS$stress
# [1] 0.1433037

#Plot Fig 2C
ggplot() + 
  geom_point(data=data.scores,aes(x=NMDS1,y=NMDS2,colour=bee_type),size=2)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+theme_bw()+
  ggsave("NMDS_SummedPhylo_norm.pdf", height=4,width=5,limitsize = FALSE)
  


#Analysis for within-group dispersal
betadisper(Tdist, samdf$bee_type, type=c("centroid") ) ->b 
p=permutest(b, permutations = 99, pairwise=TRUE)
p

#Take distances to centroid ina data frame
di = as.data.frame(b$distances)
di$sample_name = rownames(di)
dit = merge(di, samdf, by="sample_name")

#Plot Fig 2D
ggplot(data = dit, aes(x = bee_type, y = b$distances)) + 
  geom_beeswarm(aes(color=bee_type),cex=1, size=2)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_y_continuous()+
  stat_summary(data=S, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()+
  ggsave(file="DistanceToCentroid.pdf", width=4, height=4, useDingbats=FALSE)

#Relative Abundances on a Bar Graph
####################################

#Plot Fig 2E
copynums$Group =factor(copynums$Group,levels=c( "Acinetobacter","Apibacter", "Arsenophonus",    
                            "Bombella","Commensalibacter","Enterobacteriaceae",    
                            "Erwinia","Escherichia/Shigella","Fructobacillus","Gluconobacter", 
                            "Hafnia-Obesumbacterium", "Klebsiella","Kosakonia","Lactobacillus kunkeei",
                            "Pantoea","Pseudomonas",    "Raoultella",     "Rosenbergiella",
                            "Serratia", "Tatumella","Zymobacter" , "Frischella" ,"Bartonella", 
                            "Firm-5","Firm-4","Bifidobacterium",  "Snodgrassella","Gilliamella" ))

cols = c("#afa150","#d83c01","#1fa189","#c30545","#e6a5ea","#ea46b8","#c4002c",
  "#a48918","#e3079c","#5b7a81","#b801a0","#428fe6","#134c5f","#7c6c30" ,"#44c0ff","#704e00",
  "#4088b6","#43b6d4","#db5b39","#40ee2b","#a28505","#D55E00","#F0E442","#0072B2","#56B4E9","#009E73","#CC79A7","#E69F00")

 ggplot(copynums, aes(x = sample_name, y = CopyNumbers, fill = Group))+
  facet_grid(. ~ bee_type, space = "free_x", scales = "free")+
  geom_bar(position = "fill",stat = "identity",color="black") +
  scale_y_continuous(labels = percent_format())+
  scale_fill_manual(values=cols )+
  theme(panel.background = element_blank(),axis.text.x=element_text(angle=90,hjust=1,vjust=0.5),
        legend.key.size = unit(0.5, "cm"), legend.text = element_text(size=8),legend.title = element_text(size=14))+
ggsave( "GroupedBarplot_Norm.pdf",height=5,width=12,limitsize = FALSE )

#Univariate analysis of each phylotype
#######################################


# function to plot mean
plot.mean <- function(x) {
  m <- mean(x)
  c(y = m, ymin = m, ymax = m)
}
 
copynums$x.labels <- paste(copynums$bee_type, copynums$Group, sep = "\n")# to make subcathegories on x axis

#Duplicate data for 7 members
copynums7 = copynums
copynums7$x.labels <- factor(copynums7$x.labels, levels = c("F\nGilliamella","N\nGilliamella","W\nGilliamella",
                                                "F\nSnodgrassella","N\nSnodgrassella","W\nSnodgrassella",
                                                "F\nBifidobacterium","N\nBifidobacterium","W\nBifidobacterium",
                                                "F\nFirm-4","N\nFirm-4","W\nFirm-4",
                                                "F\nFirm-5","N\nFirm-5","W\nFirm-5",
                                                "F\nBartonella","N\nBartonella","W\nBartonella",
                                                "F\nFrischella","N\nFrischella","W\nFrischella"))
                                                
#This cleans up everything which is not in the list above and if the samples where the abundance is zero.
copynums7 = na.omit(copynums7)
#Put 0s to NA to have the x-axis tick but nothing will be plotted
copynums7[copynums7 ==0] = NA                                               
        
#Plot Fig 2F
ggplot(data = copynums7, aes(x = x.labels, y = CopyNumbers)) + 
  geom_beeswarm(aes(color=bee_type),cex=1, size=1.2)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_y_log10() + # logarithmic scale
  stat_summary(data=copynums7, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()+
  theme(axis.text.x = element_text(angle = 90, hjust = 1))+
ggsave("Corrected Copy numbers from community_7.pdf",height=4,width=10)        
 

#Duplicate data to plot other members which show an interesting pattern among three bee types
copynumsOthers = copynums                                         
copynumsOthers $x.labels <- factor(copynumsOthers $x.labels, levels = c(   "F\nCommensalibacter","N\nCommensalibacter","W\nCommensalibacter",
												"F\nPseudomonas","N\nPseudomonas","W\nPseudomonas",
                                                "F\nApibacter","N\nApibacter","W\nApibacter",
                                                "F\nLactobacillus kunkeei","N\nLactobacillus kunkeei","W\nLactobacillus kunkeei",
                                                "F\nBombella","N\nBombella","W\nBombella",
                                                "F\nPantoea","N\nPantoea","W\nPantoea",
                                                "F\nKlebsiella","N\nKlebsiella","W\nKlebsiella",
                                                "F\nKosakonia","N\nKosakonia","W\nKosakonia",
                                                "F\nSerratia","N\nSerratia","W\nSerratia"))
                                                
#This cleans up everything which is not in the list above and if the samples where the abundance is zero.
copynumsOthers = na.omit(copynumsOthers)
#Put 0s to NA to have the x-axis tick but nothing will be plotted
copynumsOthers[copynumsOthers ==0] = NA 

#Plot Fig 2G
ggplot(data = copynumsOthers, aes(x = x.labels, y = CopyNumbers)) + 
  geom_beeswarm(aes(color=bee_type),cex=1, size=1.2)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_y_log10() + # logarithmic scale
  stat_summary(data= copynumsOthers, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()+
  theme(axis.text.x = element_text(angle = 90, hjust = 1))+
ggsave("Corrected Copy numbers from community_Others.pdf",height=4,width=13)


#Duplicate data to plot remaining taxa for Sup.
copynumsSup = copynums   



copynumsSup $x.labels <- factor(copynumsSup $x.labels, levels = c(  "F\nAcinetobacter","N\nAcinetobacter","W\nAcinetobacter",
                                                 "F\nRosenbergiella","N\nRosenbergiella","W\nRosenbergiella",
                                                 "F\nZymobacter","N\nZymobacter","W\nZymobacter",
                                                 "F\nErwinia","N\nErwinia","W\nErwinia",
                                                 "F\nEscherichia/Shigella","N\nEscherichia/Shigella","W\nEscherichia/Shigella",
                                                 "F\nGluconobacter","N\nGluconobacter","W\nGluconobacter",
                                                 "F\nKosakonia","N\nKosakonia","W\nKosakonia",
                                                 "F\nHafnia-Obesumbacterium","N\nHafnia-Obesumbacterium","W\nHafnia-Obesumbacterium",
                                                 "F\nFructobacillus","N\nFructobacillus","W\nFructobacillus",
                                                 "F\nTatumella","N\nTatumella","W\nTatumella",
                                                 "F\nEnterobacteriaceae","N\nEnterobacteriaceae","W\nEnterobacteriaceae",
                                                 "F\nArsenophonus","N\nArsenophonus","W\nArsenophonus",
                                                 "F\nRaoultella" , "N\nRaoultella", "W\nRaoultella"))
 copynumsSup = na.omit(copynumsSup)

#Put 0s to NA to have the x-axis tick but nothing will be plotted
copynumsSup[copynumsSup ==0] = NA      
      
ggplot(data = copynumsSup, aes(x = x.labels, y = CopyNumbers)) + 
  geom_beeswarm(aes(color=bee_type),cex=1, size=1.2)+
  scale_color_manual(values = c("F" = "#B59875", "W" = "#A0CDD9", "N"= "#017B9C" ))+
  scale_y_log10() + # logarithmic scale
  stat_summary(data= copynumsSup, fun.data="plot.mean",geom="errorbar", colour="black", width=0.9, size=0.5)+ # add mean line
  theme_bw()+
  theme(axis.text.x = element_text(angle = 90, hjust = 1))+
ggsave("Corrected Copy numbers from community_Sup.pdf",height=4,width=14)      
      
                                      
#Change 0 to 1 for log transformation
copynums[copynums ==0] = 1
copynums$log_cop = log10(copynums$CopyNumbers)

#Run permutation ANOVA
t <- levels(as.factor(copynums$Group))
for (ii in t){ 
  dsub = copynums[copynums$Group==ii,]  
  cat(ii, "\n")
  print(anovaFF(dsub$log_cop, dsub$bee_type, 10000))
  cat("\n") 
  cat("\n") 
  cat("\n") 
}

#Run TUKEY for mutiple comparisions
for (ii in t){ 
  dsub = copynums[copynums$Group==ii,]  
  cat(ii, "\n")
  mod=lm(log_cop~bee_type,data=dsub)
  print(summary(glht(mod, linfct=mcp(bee_type="Tukey")), test = adjusted(type = "bonferroni")))
  cat("\n") 
  cat("\n") 
  cat("\n") 
}




