# FILE DESCRIPTION: 3_Stats_Figures1_3_S5.R ---------------------------------------------
#
# DESCRIPTION : Statistics for data presented in Fig 1, 3 and S5.
#
# USAGE: 
#
#  REQUIREMENTS:  Please load packages listed below.
#  BUGS: --
#  NOTES:  ---
#  AUTHOR:  Berra Erkosar, berra.erkosarcombe@unil.ch
#  COMPANY:  UNIL, Lausanne, Switzerland

library(vegan)
library(lme4)
library(multcomp)
library(lmerTest)
library(tidyr)
library(plyr)
library(lubridate)


setwd("")

# load user defined functions
source('2_functions.R')

# load datasets
data1 = read.csv("02_df_mm_calc.csv")
data2 = read.csv("02_df_pool_calc.csv")
data3 = read.csv("02_df_exp_calc.csv")
data4 = read.csv("02_df_ind_calc.csv")


# Statistics for Fig 1 ----------------------------------------------------------

#remove the old rownames column
data1$X =NULL
data1$Scab = as.factor(data1$Scab)
levels(data1$Scab)[levels(data1$Scab)==0] <- "no"
levels(data1$Scab)[levels(data1$Scab)==1] <- "yes"

# Compare the cell numbers for each bee type for indvidual microbiota members, pathogens, universal primers and sums. Used in Fig 1 and Fig 4.

#Replace all 0 with 1 for log transformation
data1[data1 ==0] = 1

t <- levels(data1$Target)
data1$Bee_ID <- as.factor(data1$Bee_ID)
for (ii in t){ 
  dsub = data1[data1$Target==ii,]  
  cat(ii, "\n")
  print(ttperm(log10(dsub$CellNum_norm), dsub$Bee_type ,10000))
}

sum <- aggregate(data1$CellNum_norm, by=list(Category= data1$Sample_ID, data1$Hive, data1$Date, data1$Scab, data1$Bee_type, data1$Extractor), FUN=sum) 
colnames(sum) <- c("Bee_ID","Hive","Date","Scab","Bee_type","Extractor","SUM")
ttperm(log10(sum$CellNum_norm), sum$Bee_type ,10000)


for (ii in t){ 
  dsub = data1[data1$Target==ii,]  
  cat(ii, "\n")
  print(anovaFF(log10(dsub$CellNum_norm), as.factor(dsub$Date) ,10000))
}


# Compare if there are linear trends in abundances of different microbiota members during the two foraging seasons

# select data for only foragers
dtf = data1[data1$Bee_type=="F",]
dtf$Month=droplevels(as.factor(dtf$Month))
# Recognize date as a variable
dtf = transform(dtf,  Date = as.Date(as.character(Date), "%y%m%d"))
# make new variables for month and year
dtf$month <- month(dtf$Date) 
dtf$year<- year(dtf$Date) 

# Check if there is a linear trend in Foraging season 2015 for each microbiota member
dtf2015 = dtf[dtf$year==2015,]
pdf("foragingSeason2015.pdf", width=8, height=24)
par(mfrow=c(8,1))
for (ii in t){ 
  dsub = dtf2015[dtf2015$Target==ii,]  
	boxplot(log10(CellNum_norm)~ordered(month), data=dsub, main=ii)
  cat(ii, "\n")
  print(anovaFF(log10(dsub$CellNum_norm), dsub$month ,10000))
  cat("\n") 
  cat("\n") 
}
dev.off()

# Check if there is a linear trend in Foraging season 2016 for each microbiota member
dtf2016 = dtf[dtf$year==2016,]
pdf("foragingSeason2016.pdf", width=8, height=24)
par(mfrow=c(8,1))
for (ii in t){ 
  dsub = dtf2016[dtf2016$Target==ii,]  
	boxplot(log10(CellNum_norm)~ordered(month), data=dsub, main=ii)
  cat(ii, "\n")
  print(anovaFF(log10(dsub$CellNum_norm), dsub$month ,10000))
}
dev.off()





# Multivariate Analysis of Variation (MANOVA) on community data

#Data reshaping and multivarite anova
dtbeta = data1[,c(1:6,18)]
dtbwide = dtbeta %>% spread(Target, CellNum_norm, convert = FALSE) 

#remove data for universal primers and pathogens
dtbwide$univ = NULL
dtbwide$Nc = NULL
dtbwide$Tr = NULL
dtbwide = droplevels(dtbwide)

measures = dtbwide[,6:12]
m = manova(as.matrix(measures)~dtbwide$Bee_type)
summary(m,test = "Wilks")






# Shannon's Diversity Index for each bee type

#NAs are transformed to 0, because in our datasets the NA occurs when the abundance of a species is so low that it cannot be detected. 
measures[is.na(measures)] = 0

# Calculate Shannon's diversity index.
div = diversity(measures)
Neff = exp(div)
dtbwide$Neff = Neff


#Statistics
ttperm(dtbwide$Neff, dtbwide $Bee_type, 10000)


# Statistics for Fig S2 ----------------------------------------------------------
Fp = data1[data1$Target=="Fp",]
ttperm(log10(Fp$CellNum_norm), as.factor(Fp$Scab) ,10000)







# Statistics for Fig 3 ----------------------------------------------------------

# Statistics on gut weight of individual bees from 14 hvies
#Remove the old row name column
data4$X = NULL

  #Gut weight is normally distributed and do show homoscedasticity. We therefore use simple linear models and do not do permuatations. 
mod=lm(gut_mg~Bee_type,data=data4)
anova(mod)

# Shapiro-Wilk normality test
shapiro.test(residuals(mod))

print(summary(glht(mod, linfct=mcp(Bee_type="Tukey")), test = adjusted(type = "bonferroni")))




#Statistics on experimental bees
#Remove the old row name column
data3$X = NULL
#change all 0 to 1 for log transformation
data3[data3 ==0] = 1

t3<-levels(data3$Target)


# Compare the cell numbers for each bee type for indvidual microbiota members in sugar water versus sugar water + polen fed bees.
for (ii in t3){ 
  dsub = data3[data3$Target==ii,]  
  cat(ii, "\n")
  print(ttperm(log10(dsub$CellNum_norm),dsub$Bee_type, 10000))
}


# Subset the data to work on the gut weight.
gw = data3[,c(3,6,8)]
gw=unique(gw)


#Test normality of residuals for t-test
r1 = (gw$gut_mg[gw$Bee_type=="SW"]-mean(gw$gut_mg[gw$Bee_type=="SW"]))
r2 = (gw$gut_mg[gw$Bee_type=="SW+P"]-mean(gw$gut_mg[gw$Bee_type=="SW+P"]))
res = c(r1,r2)
shapiro.test(res)


# Welch's T-test on gut weight
t.test(gw$gut_mg~gw$Bee_type)


#Regression in panel E and G were performed during plotting. Please see the script "2_Figure2_and_3.R"





# Statistics for Fig S5 ----------------------------------------------------------
#Remove the old row name column
data2$X=NULL
#change all 0 to 1 for log transformation
data2[data2 ==0] = 1


# Compare the cell numbers for each bee type for indvidual microbiota members, universal primers and sums. Used in Fig 2 and Fig 4.

t2<-levels(data2$Target)
for (ii in t2){ 
  dsub = data2[data2$Target==ii,]
  cat(ii, "\n")
  print(anovaFF(log10(dsub$CellNum_norm), dsub$Bee_type ,10000))
}

# Do Tukey's post-hoc test for pariwise comparisions
for (ii in t2){ 
  dsub = data2[data2$Target==ii,]  
  cat(ii, "\n")
  mod=lm(log10(CellNum_norm)~Bee_type,data=dsub)
  print(summary(glht(mod, linfct=mcp(Bee_type="Tukey")), test = adjusted(type = "bonferroni")))
}

  sum <- aggregate(data2$CellNum_norm, by=list(Category=data2$Sample_ID,data2$Bee_type), FUN=sum)
colnames(sum) <- c("Sample_ID","Bee_type","CellNum_norm" ) # change names
sum$Target <- "SUM"
anovaFF(log10(sum$CellNum_norm), sum$Bee_type ,10000)




# Multivariate Analysis of Variation (MANOVA) on community data
# Change data to wide orientations
gm<-data2[,c(1,4,6,18)]
dt2wide = gm %>% spread(Target, CellNum_norm, convert = FALSE) 
# Remove data for universal primers and pathogens
dt2wide$univ = NULL


#Manova: 
  m = manova(as.matrix(dt2wide[,c(3:9)])~ dt2wide $Bee_type, data= dt2wide)
summary(m,test = "Wilks")



